@@ -9,12 +9,12 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.PersonalizeRuntime 1.21.27\nVersion:         1.21.27\nBuilder"
-        " version: 7.5.3\nDocs:           "
-        " https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime//\nBoto3 docs:   "
-        "   https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize-runtime.html#PersonalizeRuntime\nOther"
+        "Type annotations for boto3.PersonalizeRuntime 1.21.31\nVersion:         1.21.31\nBuilder"
+        " version: 7.5.7\nDocs:           "
+        " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime//\nBoto3 docs: "
+        "     https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/personalize-runtime.html#PersonalizeRuntime\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
-        " https://github.com/vemel/mypy_boto3_builder/releases"
+        " https://github.com/youtype/mypy_boto3_builder/releases"
     )
 
 
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.27")
+    print("1.21.31")
 
 
 def main() -> None:
